diff --git a/fs/ext4/super.c b/fs/ext4/super.c
index 9ea71aa..c518522 100644
--- a/fs/ext4/super.c
+++ b/fs/ext4/super.c
@@ -4390,13 +4390,13 @@ static int ext4_remount(struct super_block *sb, int *flags, char *data)
 			/*
 			 * If we have an unprocessed orphan list hanging
 			 * around from a previously readonly bdev mount,
 			 * require a full umount/remount for now.
 			 */
 			if (es->s_last_orphan) {
 				ext4_msg(sb, KERN_WARNING, "Couldn't "
 				       "remount RDWR because of unprocessed "
 				       "orphan inode list.  Please "
-				       "umount/remount instead");
+				       "umount/mount instead");
 				err = -EINVAL;
 				goto restore_opts;
 			}
@@ -4390,13 +4390,13 @@ static int ext4_remount(struct super_block *sb, int *flags, char *data)
 			 * If we have an unprocessed orphan list hanging
 			 * around from a previously readonly bdev mount,
-			 * require a full umount/remount for now.
+			 * require a full umount/mount for now.
 			 */
 			if (es->s_last_orphan) {
